/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
/*****************************************************************************
 *
 *     Author:  Frederick Vong
 *
 * Modification Log:
 * -----------------
 * .01  06-01-94        vong    initial version
 *
 ***************************************************************************/

#include <Xm/Xm.h>
#include <Xm/Form.h>
#include <Xm/Label.h>
#include <Xm/PushB.h>
#include <Xm/PanedW.h>
#include <stdlib.h>
#include <iostream>

using namespace std;

char usage[] = "usage: popup <message>\n\n  message - any ascii string.\n    \\n = newline\n    \\a = bell";
void buttonCb(Widget w, XtPointer, XtPointer) {
  XtCloseDisplay(XtDisplay(w));
  exit(0);
}

int main(int argc, char *argv[]) {
  Widget toplevel;
  Widget panel;
  Widget label;
  Widget button;
  Widget actionPanel;
  Dimension w, h;
  XmString xmStr;
  char buffer[1000];
  char *str = usage;
  XtAppContext appContext;

  static String fallbackResources[] = {
    "Warning*background: red",
    "Warning*foreground: yellow",
    "Warning*fontList: 10x20",
    "Warning*panel*label*alignment: ALIGNMENT_BEGINNING",
    NULL,
  };
  toplevel = XtVaAppInitialize(&appContext, "Warning", NULL, 0,
    &argc, argv, fallbackResources, NULL);

  if (argc == 2) {
    int i = 0; int j = 0;
    char *tmp = argv[1];
    while (i < 1000) {
      if (tmp[j] == '\0') break;
      if ((tmp[j] == '\\') && (tmp[j+1] == 'n')) {
        buffer[i++] = '\n';
        j = j + 2;
      } else 
      if ((tmp[j] == '\\') && (tmp[j+1] == 'a')) {
        cerr << '\a' << endl;
        j = j + 2;
      } else 
      if ((tmp[j] == '\\') && (tmp[j+1] == 't')) {
        buffer[i++] = '\t';
        j = j + 2;
      } else {
        buffer[i++] = tmp[j];
        j++;
      }
    }
    buffer[i] = '\0';
    str = buffer;
  } else {
    cerr << '\a' << endl;
  }
  
  panel = XtVaCreateManagedWidget("panel",
	    xmPanedWindowWidgetClass, toplevel,
	    XmNsashWidth, 1,
	    XmNsashHeight, 1,
	    NULL);

  label = XtVaCreateManagedWidget("label",
	    xmLabelWidgetClass, panel,
	    NULL);


  xmStr = XmStringLtoRCreate(str,XmSTRING_DEFAULT_CHARSET);
  XtVaSetValues(label,
	XmNlabelString, xmStr,
	NULL);
  XmStringFree(xmStr);

  actionPanel = XtVaCreateWidget("actionArea",
	    xmFormWidgetClass, panel,
	    XmNfractionBase, 3,
	    NULL);
  button = XtVaCreateManagedWidget("dismiss",
	    xmPushButtonWidgetClass, actionPanel,
	    XmNtopAttachment, XmATTACH_FORM,
	    XmNbottomAttachment, XmATTACH_FORM,
	    XmNleftAttachment, XmATTACH_POSITION,
	    XmNleftPosition, 1,
	    XmNrightAttachment, XmATTACH_POSITION,
	    XmNrightPosition, 2,
	    NULL);

  XtAddCallback(button, XmNactivateCallback, buttonCb, NULL);

  XtVaGetValues(button,
	XmNheight, &h,
	NULL);
  XtVaSetValues(actionPanel,
	XmNpaneMaximum, h,
	XmNpaneMinimum, h,
	NULL);
  XtManageChild(actionPanel);
  XtManageChild(panel);
  XtRealizeWidget(toplevel);
  XtVaGetValues(toplevel,
	XmNwidth, &w,
	XmNheight, &h,
	NULL);
  XtVaSetValues(toplevel,
	XmNminWidth, w,
	XmNmaxWidth, w,
	XmNminHeight, h,
	XmNmaxHeight, h,
	NULL);
  XtAppMainLoop(appContext);
  return 0;
}
